@@ -56,9 +56,15 @@ class HeatExchanger(Component):
 
     Image
 
-    .. image:: _images/HeatExchanger.svg
-       :alt: alternative text
+    .. image:: /api/_images/HeatExchanger.svg
+       :alt: flowsheet of the heat exchanger
        :align: center
+       :class: only-light
+
+    .. image:: /api/_images/HeatExchanger_darkmode.svg
+       :alt: flowsheet of the heat exchanger
+       :align: center
+       :class: only-dark
 
     Parameters
     ----------
