@@ -129,6 +129,7 @@ def test_set_attr_errors():
 
     # NotImplementedError
     set_attr_NotImplementedError(conn, Td_bp=Ref(conn, 1, 0))
+    set_attr_NotImplementedError(conn, x=Ref(conn, 1, 0))
 
 
 def test_get_attr_errors():
@@ -514,9 +515,8 @@ class TestNetworkErrors:
         source = Source('label')
         sink = Sink('label')
         a = Connection(source, 'out1', sink, 'in1')
-        self.nw.add_conns(a)
         with raises(TESPyNetworkError):
-            self.nw.check_network()
+            self.nw.add_conns(a)
 
     def test_missing_offdesign_path(self):
         source = Source('source')
